#!/bin/bash

# Dumps all verinice accounts and their assigned groups to a csv file with a time
# stamp. Provide the full qualified filename (including path) as first commandline parameter,
# or use the default instead (by not passing any parameter)
# The following information will be dumped:
#
# 1. verinice username (login name)
# 2. assigned verinice user group
# 
# every combination of username / usergroup leads to one line in the result
#
# @author Sebastian Hagedorn <sh@sernet.de>
# @version 0.1

#Path of the table dump
output_file="/tmp/verinice_account_data_`date +%Y-%m-%d-%H-%M-%S`.csv"

# just print first commandline parameter
if [ -z "$1" ]; then
	echo -e "writing verinice account-data to:\t ${output_file}"
else
	echo -e "writing verinice account-data to:\t ${1}"
	output_file=$1
fi



# verinice Database 
database="verinicedb"

# verinice user
username="verinice"

# The password for the postgres user. This is not recommended, since
# some unix os allow non-root users to see enviromnent variables. It
# is also possible to use a password file or allow the verinice user
# in general connecting to the verinicedb from localhost. (this is
# done in /data/pg_data/pg_hba.conf). Then this variable can be unset.
export PGPASSWORD="verinice"



query="\copy (select p1.propertyvalue AS USERNAME, p2.propertyvalue AS GROUP FROM properties p1 JOIN propertylist pl1 ON p1.properties_id=pl1.dbid JOIN entity e1 ON pl1.typedlist_id=e1.dbid JOIN propertylist pl2 ON e1.dbid=pl2.typedlist_id JOIN properties p2 ON pl2.dbid=p2.properties_id where p1.propertytype = 'configuration_benutzername' and p2.propertytype = 'configuration_rolle')  TO '${output_file}' CSV HEADER"

psql -d $database -U $username -w -c "${query}" 

#remove the password from enviromnent
unset PGPASSWORD

exit
